#!/bin/sh
export LANG=en_US.UTF-8
export GTK2_RC_FILES=/usr/share/themes/Xfce/gtk-2.0/gtkrc
export WALLPAPER=/usr/share/pyra/wallpapers/official/pyra-a-720.png

xmodmap /etc/skel/.Xmodmap

hsetroot -cover $WALLPAPER

zenity --question --title="Pyras Box has been opened." --text="Welcome!\n\nPyra's Box has been opened.\n\nThis wizard will help you setting up your $pnd_version OpenPyra handheld before the first use.\n\nYou will be asked a few simple questions to personalise and configure your device.\n\nDo you want to set up your unit now or shut the unit down and do it later?" --ok-label="Start now" --cancel-label="Shutdown"


#calibrate touchscreen
if zenity --question --title="Touchscreen" --text="Calibrate touchscreen ?" --ok-label="Yes" --cancel-label="No"; then          
  /usr/share/pyra/scripts/pyra-touchscreen-calibrate.sh
fi

# Setup the full name and username.

while ! name=$(zenity --title="Please enter your full name" --entry --text "Please enter your full name.") || [ "x$name" = "x" ] ; do
  zenity --title="Error" --error --text="Please try again." --timeout 6
done

username_guess=$(echo "$name" | cut -d" " -f1 | tr A-Z a-z)

while ! username=$(zenity --title="Enter your username" --entry --text "Please choose a short username.\n\nIt should be all lowercase and contain only letters and numbers." --entry-text "$username_guess") || [ "x$username" = "x" ] ; do
  zenity --title="Error" --error --text="Please try again." --timeout 6
done

while ! useradd -m --shell /bin/bash -c "$name,,," -G sudo,audio,bluetooth,plugdev "$username" ; do
  username=$(zenity --title="Please check username" --entry --text "Please ensure that your username consists of only\nletters and numbers and is not already in use on the system." --entry-text "$username")
done

# ----
# Setup the users password.

password=""
while [ x$password = x ] ; do
  password1=$(zenity --title=Password --entry --text="Please choose a new password." --hide-text)
  password2=$(zenity --title=Confirm --entry --text="Confirm your new password." --hide-text)
  if [ $password1 != $password2 ] ; then 
    zenity --title="Error" --error --text="The passwords do not match.\n\nPlease try again." --timeout 6
  else 
    if [ x$password1 = x ] ; then
      zenity --title="Error" --error --text="Password cannot be blank!\n\nPlease try again." --timeout 6
    else
      password=$password1
    fi
  fi
done

passwd "$username" <<EOF
$password
$password
EOF

# ---
# encrypt home dir

#if zenity --question --title="Encryption" --text="Encrypt home dir ? \n\nIf enabled your home dir will be encrypted with ecryptfs." --ok-label="Yes" --cancel-label="No"; then     	
#  modprobe ecryptfs
#  LOGINPASS=$password ecryptfs-migrate-home -u "$username"
#fi

# ---
#  Set hostname

while ! hostname=$(zenity --title="Name your Pyra" --entry --text "Please choose a name for your Pyra.\n\nIt should only contain letters, numbers and dashes, no spaces." --entry-text "$username-pyra") || [ "x$hostname" = "x" ]; do 
	zenity --title="Error" --error --text="Please try again."
	done

hostnamectl set-hostname $hostname
# update /etc/hosts
cp /etc/hosts /etc/hosts.back
{
echo "127.0.0.1		localhost $hostname"
sed '/^127.0.0.1/d' /etc/hosts.back
}>/etc/hosts

# --
# Firewall
if zenity --question --title="Firewall" --text="Enable Firewall ? \n\nIf enabled a firewall is set up to allow incoming ssh traffic, blocking everything else." --ok-label="Yes" --cancel-label="No"; then     	
  ufw allow ssh
  ufw enable
else
  ufw disable
fi


# ----
# audio settings

/usr/share/pyra/scripts/pyra-init-alsa.sh


# ----
# slim theme
if [ -f /etc/slim.conf ]
then
	sed -i "s/.*current_theme.*/current_theme pyra/g" /etc/slim.conf
fi

dpkg-reconfigure openssh-server
dpkg-reconfigure -fgnome keyboard-configuration
dpkg-reconfigure -fgnome tzdata
dpkg-reconfigure -fgnome locales

touch /var/lib/pyra/first-run.done

zenity --info --text "Done!"

poweroff
